@@ -213,7 +213,7 @@ static AtkStateSet *
 gail_cell_ref_state_set (AtkObject *obj)
 {
   GailCell *cell = GAIL_CELL (obj);
-  g_return_val_if_fail (cell->state_set, NULL);
+  g_assert (cell->state_set);
 
   g_object_ref(cell->state_set);
   return cell->state_set;
@@ -303,7 +303,8 @@ gail_cell_get_index_in_parent (AtkObject *obj)
 {
   GailCell *cell;
 
-  g_return_val_if_fail (GAIL_IS_CELL (obj), 0);
+  g_assert (GAIL_IS_CELL (obj));
+
   cell = GAIL_CELL (obj);
   if (atk_state_set_contains_state (cell->state_set, ATK_STATE_STALE))
     if (cell->refresh_index)
@@ -317,7 +318,7 @@ gail_cell_get_index_in_parent (AtkObject *obj)
 static void
 gail_cell_atk_action_interface_init (AtkActionIface *iface)
 {
-  g_return_if_fail (iface != NULL);
+  g_assert (iface != NULL);
 
   iface->get_n_actions = gail_cell_action_get_n_actions;
   iface->do_action = gail_cell_action_do_action;
@@ -379,7 +380,6 @@ gail_cell_remove_action (GailCell *cell,
   list_node = g_list_nth (cell->action_list, action_index);
   if (!list_node)
     return FALSE;
-  g_return_val_if_fail (list_node->data != NULL, FALSE);
   _gail_cell_destroy_action_info (list_node->data, NULL);
   cell->action_list = g_list_remove_link (cell->action_list, list_node);
   return TRUE;
@@ -403,7 +403,8 @@ gail_cell_remove_action_by_name (GailCell    *cell,
 	  break;
 	}
     }
-  g_return_val_if_fail (action_found, FALSE);
+  if (!action_found)
+    return FALSE;
   _gail_cell_destroy_action_info (list_node->data, NULL);
   cell->action_list = g_list_remove_link (cell->action_list, list_node);
   return TRUE;
@@ -430,7 +431,7 @@ _gail_cell_destroy_action_info (gpointer action_info,
                                 gpointer user_data)
 {
   ActionInfo *info = (ActionInfo *)action_info;
-  g_return_if_fail (info != NULL);
+  g_assert (info != NULL);
   g_free (info->name);
   g_free (info->description);
   g_free (info->keybinding);
@@ -504,7 +505,8 @@ gail_cell_action_do_action (AtkAction *action,
   ActionInfo *info = _gail_cell_get_action_info (cell, index);
   if (info == NULL)
     return FALSE;
-  g_return_val_if_fail (info->do_action_func, FALSE);
+  if (info->do_action_func == NULL)
+    return FALSE;
   if (cell->action_idle_handler)
     return FALSE;
   cell->action_func = info->do_action_func;
@@ -517,17 +519,21 @@ idle_do_action (gpointer data)
 {
   GailCell *cell;
 
+  GDK_THREADS_ENTER ();
+
   cell = GAIL_CELL (data);
   cell->action_idle_handler = 0;
   cell->action_func (cell);
 
+  GDK_THREADS_LEAVE ();
+
   return FALSE;
 }
 
 static void
 atk_component_interface_init (AtkComponentIface *iface)
 {
-  g_return_if_fail (iface != NULL);
+  g_assert (iface != NULL);
 
   iface->get_extents = gail_cell_get_extents;
   iface->grab_focus = gail_cell_grab_focus;
@@ -544,13 +550,12 @@ gail_cell_get_extents (AtkComponent *component,
   GailCell *gailcell;
   AtkObject *cell_parent;
 
-  g_return_if_fail (GAIL_IS_CELL (component));
+  g_assert (GAIL_IS_CELL (component));
 
   gailcell = GAIL_CELL (component);
 
   cell_parent = gtk_widget_get_accessible (gailcell->widget);
 
-  g_return_if_fail (GAIL_IS_CELL_PARENT (cell_parent));
   gail_cell_parent_get_cell_extents (GAIL_CELL_PARENT (cell_parent), 
                                    gailcell, x, y, width, height, coord_type);
 }
@@ -561,13 +566,12 @@ gail_cell_grab_focus (AtkComponent *component)
   GailCell *gailcell;
   AtkObject *cell_parent;
 
-  g_return_val_if_fail (GAIL_IS_CELL (component), FALSE);
+  g_assert (GAIL_IS_CELL (component));
 
   gailcell = GAIL_CELL (component);
 
   cell_parent = gtk_widget_get_accessible (gailcell->widget);
 
-  g_return_val_if_fail (GAIL_IS_CELL_PARENT (cell_parent), FALSE);
   return gail_cell_parent_grab_focus (GAIL_CELL_PARENT (cell_parent), 
                                       gailcell);
 }
